import axios from "axios";
import { v4 as uuid } from "uuid";
/**
 * dePay class
 */
export default class dePay {
  constructor(config) {
    this.checkout = {
      _path: `/payments`,
      init: async (body) => {
        let res = await this._post(this.checkout._path, body);
        return res;
      },
      status: async (PAYMENT_ID) => {
        let res = await this._get(
          this.checkout._path + `/${PAYMENT_ID}/status`
        );
        return res;
      },
    };
    this.apiV = "v1";
    this.config = config;
    this.headers = {
      "Content-Type": "application/json",
      "APP-ID": this.config.appId,
      "API-SECRET": this.config.apiSecret,
      "Request-Id": uuid(),
      Accept: "application/json",
    };
    this.baseUrl = `https://application-api.depay.cash/${this.apiV}`;
    if (config.sandbox === true)
      this.baseUrl = `https://stg-application.depay.cash/${this.apiV}`;
  }
  async _post(path, body, params) {
    let res = await axios.post(this.baseUrl + path, body, {
      params,
      headers: this.headers,
    });
    return res.data;
  }
  async _get(path, params) {
    let res = await axios.get(this.baseUrl + path, {
      params,
      headers: this.headers,
    });
    return res.data;
  }
}
