import axios from "axios";
import { v4 as uuid } from "uuid";
import { Params, Data, dePayConfig, Headers } from "./types/index";
import { Payments } from "./types/payments";

/**
 * dePay class
 */
export default class dePay {
  private config: dePayConfig;
  private apiV: String;
  private baseUrl: string;
  private headers: Headers;

  constructor(config: dePayConfig) {
    this.apiV = "v1";
    this.config = config;
    this.headers = {
      "Content-Type": "application/json",
      "APP-ID": this.config.appId,
      "API-SECRET": this.config.apiSecret,
      "Request-Id": uuid(),
      Accept: "application/json",
    };
    this.baseUrl = `https://application-api.depay.cash/${this.apiV}`;
    if (config.sandbox === true)
      this.baseUrl = `https://stg-application.depay.cash/${this.apiV}`;
  }

  private async _post(path: string, body: Data, params?: Params) {
    let res = await axios.post(this.baseUrl + path, body, {
      params,
      headers: this.headers,
    });
    return res.data;
  }

  private async _get(path: string, params?: Params) {
    let res = await axios.get(this.baseUrl + path, {
      params,
      headers: this.headers,
    });
    return res.data;
  }

  checkout = {
    _path: `/payments`,
    init: async (body: Payments.init.Body): Promise<Payments.init.Result> => {
      let res = await this._post(this.checkout._path, body);
      return res;
    },

    status: async (
      PAYMENT_ID: Payments.status.PAYMENT_ID
    ): Promise<Payments.status.Result> => {
      let res = await this._get(this.checkout._path + `/${PAYMENT_ID}/status`);
      return res;
    },
  };
}
